#define single_input 256
#define file_input 257
#define eval_input 258
#define funcdef 259
#define parameters 260
#define varargslist 261
#define fpdef 262
#define fplist 263
#define stmt 264
#define simple_stmt 265
#define small_stmt 266
#define expr_stmt 267
#define print_stmt 268
#define del_stmt 269
#define pass_stmt 270
#define flow_stmt 271
#define break_stmt 272
#define continue_stmt 273
#define return_stmt 274
#define raise_stmt 275
#define import_stmt 276
#define dotted_name 277
#define global_stmt 278
#define access_stmt 279
#define accesstype 280
#define exec_stmt 281
#define compound_stmt 282
#define if_stmt 283
#define while_stmt 284
#define for_stmt 285
#define try_stmt 286
#define except_clause 287
#define suite 288
#define test 289
#define and_test 290
#define not_test 291
#define comparison 292
#define comp_op 293
#define expr 294
#define xor_expr 295
#define and_expr 296
#define shift_expr 297
#define arith_expr 298
#define term 299
#define factor 300
#define atom 301
#define lambdef 302
#define trailer 303
#define subscript 304
#define exprlist 305
#define testlist 306
#define dictmaker 307
#define classdef 308
#define arglist 309
#define argument 310
